# Quasar

## What is Quasar?

Quasar is an abstract library for creating and evaluating quantum computing
circuits.  It also can be a way of transforming those circuits to be run
natively on a variety of QC architectures.

This public version of Quasar is used to create circuits
that can be evaluated on QC Ware's *Forge* platform, but also can do
some evaluations locally with a classical simulation backend.
